##  Create a Custom Modernization Dashboard
For enhanced storytelling and decision-making, use SAP LeanIX custom dashboards to combine multiple visualizations into a cohesive narrative. Create an overview with the most important data points:
  * Application landscape report with 6R in the following versions:
    * Before
    * After modernization
  * Application portfolio report with the axes 6R and business criticality
  * Circle map
  * Initiative roadmap with affected applications


Example of Custom Modernization Dashboard
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio188713000cfc4ea1bc653a35086c0643_LowRes.png)
